@@ -73,56 +73,59 @@ class Container:
         return self.services[key]
 
     async def reset(self, key: Key) -> "Container":
+        """Finalize, cleanup, and remove an service from the container instance."""
         key = _get_key(key)
-        await self.cleanup(key)
+        await self._finalize(key)
+        await self._cleanup(key)
         del self.services[key]
         return self
 
     async def reset_all(self) -> "Container":
-        await self.cleanup_all()
+        """Finalize, cleanup, and remove all services from the container instance."""
+        await self._finalize_all()
+        await self._cleanup_all()
         self.services = {}
         return self
 
-    async def finalize(self, key: Key):
+    async def close(self) -> "Container":
+        """Finalize, cleanup, and remove all services from the container instance. This is an
+        alias for reset_all.
+        """
+        return await self.reset_all()
+
+    async def _finalize(self, key: str):
         """Finalize a single service if it has been booted and it has a finalize function
         registered.
         """
-        key = _get_key(key)
         if key not in self.services:
             return
 
         instance = self.services[key]
         await self.container_definition.get(key).run_finalize(instance)
 
-    async def finalize_all(self):
+    async def _finalize_all(self):
         """Iterate through all services that have been created and call the associated finalize
         method for that service, if there is one.
         """
         for key in self.services:
-            await self.finalize(key)
+            await self._finalize(key)
 
-    async def cleanup(self, key: Key):
+    async def _cleanup(self, key: str):
         """Cleanup a single service if it has been booted and it has a cleanup function
         registered.
         """
-        key = _get_key(key)
         if key not in self.services:
             return
 
         instance = self.services[key]
         await self.container_definition.get(key).run_cleanup(instance)
 
-    async def cleanup_all(self):
+    async def _cleanup_all(self):
         """Iterate through all services that have been created, and call the associated cleanup
         method for that service, if there is one.
         """
         for key in self.services:
-            await self.cleanup(key)
-
-    async def close(self):
-        """Close the container instance but finalizing and cleaning up all instances."""
-        await self.finalize_all()
-        await self.cleanup_all()
+            await self._cleanup(key)
 
 
 class ContainerDefinition:
